# VKMusix [![PyPI version](https://d25lcipzij17d.cloudfront.net/badge.svg?id=py&r=r&ts=1683906897&type=6e&v=4.3.0&x2=0)](https://pypi.org/project/vkmusix)

## Установка и обновление
```bash
pip install --upgrade vkmusix
```

## Быстрый старт
```python
from vkmusix import Client

client = Client()

tracks = client.searchTracks(
    query="Маленький ярче",
    limit=10,
    
)

print(tracks)

client.close()
```

## Основные возможности

**• Работа в синхронном и асинхронном режимах.**

**• Интуитивно понятные названия методов, параметров, классов и атрибутов, а также подробная документация.**

**• Работа от имени нескольких аккаунтов одновременно благодаря поддержке прокси.**

**• Возможность подключения авторешения капч через сервис [RuCaptcha](https://rucaptcha.com).**

**• Лёгкий и простой поиск исполнителей, альбомов, треков, плейлистов, или всех типов сразу, в пару строк кода.**

**• Доступ к текстам треков и функция для их загрузки в _.ts_, _.mp3_ и _.opus_, а также ссылкам на обложки в формате _.jpg_ для треков, альбомов и плейлистов.**

**• Управление своей музыкальной коллекцией и музыкой групп: добавление или удаление треков, альбомов и плейлистов легко и быстро.**

**• Загрузка своих треков на платформу за считанные секунды.**

**• Клонирование альбомов и плейлистов других пользователей, как будто их создали вы, одной строчкой кода.**

**• Функция `client.api()` для отправки запроса к любому методу ВКонтакте API.**
